==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","sminiz");
define("_OK","Tamam!");
define("_COMMENT","yorum");
define("_CONFIGURE","Dzenle");
define("_LOGINCREATE","Hesap A/Yarat");
define("_THRESHOLD","Balang");
define("_NOCOMMENTS","Yorum Yok");
define("_NESTED","-ie");
define("_FLAT","Dz");
define("_THREAD","Sral");
define("_OLDEST","Eski Baa");
define("_NEWEST","Yeni Baa");
define("_HIGHEST","Yksek Skorlar Baa");
define("_COMMENTSWARNING","Yorumlar yazarlarna aittir. eriklerinden biz sorumlu tutulamayz.");
define("_SCORE","Skor:");
define("_USERINFO","Kullanc Bilgisi");
define("_READREST","Bu yorumun devamn oku...");
define("_REPLY","Cevap Ver");
define("_REPLYMAIN","Yorum Ekle");
define("_NOSUBJECT","Konu Yok");
define("_NOANONCOMMENTS","Anonim kullanc yorum yazamaz, ltfen <a href=\"modules.php?name=Your_Account&op=new_user\">kayt olun</a>");
define("_PARENT","Yukar");
define("_ROOT","Kk");
define("_UCOMMENT","Yorum");
define("_ALLOWEDHTML","zin Verilen HTML:");
define("_POSTANON","Anonim Olarak Gnder");
define("_EXTRANS","HTML tag'leri metne");
define("_HTMLFORMATED","HTML Biimli");
define("_PLAINTEXT","Metin Biimli");
define("_ONN","stnde...");
define("_SUBJECT","Konu");
define("_SURVEYCOM","Ankete Yorum Ekle");
define("_SURVEYCOMPRE","Anket Yorumu nizleme");
define("_NOTRIGHT","Bu fonksiyona deer geirilirken sorun olutu. Bu mesaj sadece ilerin yoldan kmasn engellemek iindir");
define("_DIRECTCOM","Direkt Anket Yorumu...");
define("_SENDAMSG","Mesaj Gnder");
define("_PASTSURVEYS","Eski Anketler");



define("_LVOTES","oy");
define("_TOTALVOTES","Toplam Oy:");
define("_VOTING","Oylama");
define("_OTHERPOLLS","Dier Anketler");
define("_CURRENTSURVEY","Aktif Anket");
define("_CURRENTPOLLRESULTS","Aktif Anket Sonular");
define("_PREVIEW","nizleme");
define("_REFRESH","Yenile");
define("_SURVEYS","Anketler");
define("_ATTACHEDTOARTICLE","- Eklendii haber:");
define("_SURVEYSATTACHED","Haberlere Bal Anketler");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","sminiz");
define("_OK","Tamam!");
define("_COMMENT","yorum");
define("_CONFIGURE","Dzenle");
define("_LOGINCREATE","Hesap A/Yarat");
define("_THRESHOLD","Balang");
define("_NOCOMMENTS","Yorum Yok");
define("_NESTED","-ie");
define("_FLAT","Dz");
define("_THREAD","Sral");
define("_OLDEST","Eski Baa");
define("_NEWEST","Yeni Baa");
define("_HIGHEST","Yksek Skorlar Baa");
define("_COMMENTSWARNING","Yorumlar yazarlarna aittir. eriklerinden biz sorumlu tutulamayz.");
define("_SCORE","Skor:");
define("_USERINFO","Kullanc Bilgisi");
define("_READREST","Bu yorumun devamn oku...");
define("_REPLY","Cevap Ver");
define("_REPLYMAIN","Yorum Ekle");
define("_NOSUBJECT","Konu Yok");
define("_NOANONCOMMENTS","Anonim kullanc yorum yazamaz, ltfen <a href=\"modules.php?name=Your_Account&op=new_user\">kayt olun</a>");
define("_PARENT","Yukar");
define("_ROOT","Kk");
define("_UCOMMENT","Yorum");
define("_ALLOWEDHTML","zin Verilen HTML:");
define("_POSTANON","Anonim Olarak Gnder");
define("_EXTRANS","HTML tag'leri metne");
define("_HTMLFORMATED","HTML Biimli");
define("_PLAINTEXT","Metin Biimli");
define("_ONN","stnde...");
define("_SUBJECT","Konu");
define("_SURVEYCOM","Ankete Yorum Ekle");
define("_SURVEYCOMPRE","Anket Yorumu nizleme");
define("_NOTRIGHT","Bu fonksiyona deer geirilirken sorun olutu. Bu mesaj sadece ilerin yoldan kmasn engellemek iindir");
define("_DIRECTCOM","Direkt Anket Yorumu...");
define("_SENDAMSG","Mesaj Gnder");
define("_PASTSURVEYS","Eski Anketler");



define("_LVOTES","oy");
define("_TOTALVOTES","Toplam Oy:");
define("_VOTING","Oylama");
define("_OTHERPOLLS","Dier Anketler");
define("_CURRENTSURVEY","Aktif Anket");
define("_CURRENTPOLLRESULTS","Aktif Anket Sonular");
define("_PREVIEW","nizleme");
define("_REFRESH","Yenile");
define("_SURVEYS","Anketler");
define("_ATTACHEDTOARTICLE","- Eklendii haber:");
define("_SURVEYSATTACHED","Haberlere Bal Anketler");

?>
